﻿namespace UltraDayViewLines
{
    using System.Drawing;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinSchedule.DayView;

    internal class DF : IUIElementDrawFilter
    {
        private int intervals;
        private Pen pen;

        public DF(Pen pen, int intervals)
        {
            this.intervals = intervals;
            this.pen = pen;
        }

        /// <summary>
        /// Number of minor intervals
        /// </summary>
        internal int Intervals
        {
            get { return this.intervals; }
            set { this.intervals = value; }
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            if(drawParams.Element is TimeSlotDescriptorUIElement)
            {
                var rect = drawParams.Element.Rect;

                // Draw top line
                var left = rect.Left;
                var top = rect.Top;
                var right = rect.Right - 4;
                drawParams.Graphics.DrawLine(this.pen, left + 4, top, right, top);

                //  Draw minor interval lines
                if(this.Intervals > 0)
                {
                    left += 42;
                    for(int i = 1; i < this.Intervals; i++)
                    {
                        top += rect.Height / this.Intervals;
                        drawParams.Graphics.DrawLine(this.pen, left, top, right, top);
                    }
                }

                //  Return true to suppress any further drawing in this phase
                return true;
            }

            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if(drawParams.Element is TimeSlotDescriptorUIElement)
            {
                return DrawPhase.BeforeDrawForeground;
            }

            return DrawPhase.None;
        }
    }
}



/*
 * UltraDayViewUIElement, Location = {X=0,Y=0,Width=429,Height=542}
    MainUIElement, Location = {X=0,Y=0,Width=410,Height=542}
        TopLeftAreaUIElement, Location = {X=0,Y=0,Width=67,Height=59}
        HeadingAreaUIElement, Location = {X=67,Y=0,Width=343,Height=59}
            DayHeaderAreaUIElement, Location = {X=67,Y=0,Width=343,Height=18}
                DayHeaderUIElement, Location = {X=68,Y=1,Width=341,Height=17}
                    TextUIElement, Location = {X=179,Y=1,Width=119,Height=17}
            AllDayEventAreaUIElement, Location = {X=67,Y=18,Width=343,Height=41}
                AllDayEventAreaDayUIElement, Location = {X=67,Y=18,Width=343,Height=41}
        DayAreaUIElement, Location = {X=67,Y=59,Width=343,Height=483}
            DayUIElement, Location = {X=67,Y=59,Width=343,Height=483}
                TimeSlotUIElement, Location = {X=67,Y=59,Width=343,Height=21}
                TimeSlotUIElement, Location = {X=67,Y=80,Width=343,Height=21}
                ...
                TimeSlotUIElement, Location = {X=67,Y=500,Width=343,Height=21}
                TimeSlotUIElement, Location = {X=67,Y=521,Width=343,Height=21}
        TimeSlotDescriptorAreaContainerUIElement, Location = {X=0,Y=58,Width=67,Height=484}
            TimeSlotDescriptorAreaUIElement, Location = {X=0,Y=58,Width=67,Height=484}
                TimeSlotDescriptorUIElement, Location = {X=0,Y=58,Width=67,Height=84} [Active]
                    HourUIElement, Location = {X=-14,Y=60,Width=58,Height=33}
                    MinuteUIElement, Location = {X=40,Y=59,Width=27,Height=20}
                ...
                TimeSlotDescriptorUIElement, Location = {X=0,Y=478,Width=67,Height=84}
                    HourUIElement, Location = {X=-14,Y=480,Width=58,Height=33}
                    MinuteUIElement, Location = {X=40,Y=479,Width=27,Height=20}
    ScrollBarUIElement, Location = {X=410,Y=0,Width=19,Height=542}
        ScrollArrowUIElement, Location = {X=410,Y=0,Width=19,Height=19}
        ScrollArrowUIElement, Location = {X=410,Y=523,Width=19,Height=19}
        ScrollTrackUIElement, Location = {X=410,Y=19,Width=19,Height=504}
            ScrollThumbUIElement, Location = {X=410,Y=187,Width=19,Height=121}
            ScrollTrackSubAreaUIElement, Location = {X=410,Y=19,Width=19,Height=168}
            ScrollTrackSubAreaUIElement, Location = {X=410,Y=308,Width=19,Height=215}
*/
